setGeneric("summaryShort", function(object, ...) {
    return(standardGeneric("summaryShort"))
})

setGeneric("getCutoff", function(object, alpha, revDirec = FALSE, usedFit = NULL, 
    ...) {
    return(standardGeneric("getCutoff"))
})

setGeneric("plotCutoff", function(object, ...) {
    return(standardGeneric("plotCutoff"))
})
